#include "testlib.h"
#include <vector>
#include <algorithm>

using namespace std;

const int INF = 2000000000;

class SegTree {
private:
    vector<int> it;
    int sz;

    int getVal(int u, int L, int R, int i) {
        if (R - L == 1) {
            return it[u];
        }
        int M = (L + R) / 2;
        if (i < M) {
            return it[u] + getVal(2 * u + 1, L, M, i);
        } else {
            return it[u] + getVal(2 * u + 2, M, R, i);
        }
    }

    void add(int u, int L, int R, int l, int r, int v) {
        if (l >= R || L >= r) {
            return;
        }
        if (l <= L && R <= r) {
            it[u] += v;
            return;
        }
        int M = (L + R) / 2;
        add(2 * u + 1, L, M, l, r, v);
        add(2 * u + 2, M, R, l, r, v);
    }

public:
    SegTree(int s) : sz(s) {
        it.resize(4 * sz);
    }

    int getVal(int i) {
        return getVal(0, 0, sz, i);
    }

    void addVal(int l, int r, int v) {
        add(0, 0, sz, l, r, v);
    }
};

int main(int argc, char* argv[]) {
    registerTestlibCmd(argc, argv);

    int n = inf.readInt();
    vector<int> b(n), g(n);
    for (int i = 0; i < n; i++) {
        b[i] = inf.readInt();
    }
    for (int i = 0; i < n; i++) {
        g[i] = inf.readInt();
    }

    vector<int> db(n, -1), dg(n, -1);
    for (int i = 0; i < n; i++) {
        int pb = ouf.readInt(1, n, format("pb[%d]", i)) - 1;
        int pg = ouf.readInt(1, n, format("pg[%d]", i)) - 1;
        if (db[pb] != -1) {
            quitf(_wa, "duplicate boy %d", pb + 1);
        }
        if (dg[pg] != -1) {
            quitf(_wa, "duplicate girl %d", pg + 1);
        }
        db[pb] = dg[pg] = abs(b[pb] - g[pg]);
    }

    vector<pair<int, int>> gs(n);
    for (int i = 0; i < n; i++) {
        gs[i] = {g[i], dg[i]};
    }
    sort(gs.begin(), gs.end());

    vector<pair<int, int>> bs(n);
    for (int i = 0; i < n; i++) {
        bs[i] = {b[i], db[i]};
    }
    sort(bs.begin(), bs.end());

    vector<int> bl(n), br(n);
    for (int i = 0; i < n; i++) {
        int c = bs[i].first;
        int rad = bs[i].second;

        int L = -1;
        int R = n;
        while (R - L > 1) {
            int M = (L + R) / 2;
            if (gs[M].first > c - rad) {
                R = M;
            } else {
                L = M;
            }
        }
        int left = R;

        L = -1;
        R = n;
        while (R - L > 1) {
            int M = (L + R) / 2;
            if (gs[M].first < c + rad) {
                L = M;
            } else {
                R = M;
            }
        }
        int right = L;

        bl[i] = left;
        br[i] = right;
    }

    vector<int> gl(n), gr(n);
    for (int i = 0; i < n; i++) {
        int c = gs[i].first;
        int rad = gs[i].second;

        int L = -1;
        int R = n;
        while (R - L > 1) {
            int M = (L + R) / 2;
            if (bs[M].first > c - rad) {
                R = M;
            } else {
                L = M;
            }
        }
        int left = R;

        L = -1;
        R = n;
        while (R - L > 1) {
            int M = (L + R) / 2;
            if (bs[M].first < c + rad) {
                L = M;
            } else {
                R = M;
            }
        }
        int right = L;

        gl[i] = left;
        gr[i] = right;
    }

    vector<int> bans(n);
    vector<vector<pair<int, int>>> evs(n + 1);
    for (int i = 0; i < n; i++) {
        evs[bl[i]].emplace_back(-1, i);
        evs[br[i] + 1].emplace_back(1, i);
    }

    SegTree st(n);
    for (int x = 0; x < n + 1; x++) {
        for (auto e : evs[x]) {
            bans[e.second] += e.first * st.getVal(e.second);
        }
        if (x < n) {
            st.addVal(gl[x], gr[x] + 1, 1);
        }
    }

    for (int i = 0; i < n; i++) {
        if (bans[i] > 0) {
            quitf(_wa, "there is a pair with temptation, boy coordinate = %d", bs[i].first);
        }
    }

    quitf(_ok, "correct matching");
}
